@@ -1,18 +1,25 @@
 # run with -l switch
+
+#
+# check a bunch of stuff.
+# write #define/#undef to file given in ARGV[0].
+#
+
 use strict;
 use warnings;
 use Devel::CheckLib;
 
-my $out  = $ARGV[0];
-my $conf = generate_conf();
+my ($out, $flagfile) = @ARGV;
+my $conf  = [];
+my $flags = [];
 
-print 'Writing ', $out;
-write_conf($conf, $out);
+generate_conf($conf, $flags);
+write_conf   ($conf, $out);
 
 exit 0;
 
 sub generate_conf {
-    my $defines = [];
+    my ($defines, $flags) = @_;
     my $longest = 0;
 
     # dont use the uuidd.
@@ -59,7 +66,6 @@ sub generate_conf {
         # this must come after HAVE_SYS_TIME_H check
         try_struct_timeval ($check, \$longest, $defines);
     }
-
 #
 # these havent been handled yet. do they need to be?
 #
@@ -70,8 +76,6 @@ sub generate_conf {
 #
 #   TLS
 #
-
-    return $defines;
 }
 
 sub try_headers {
